@@ -4,7 +4,7 @@ use warnings;
 use warnings::register;
 
 # ABSTRACT: An extension of the File::stat module, provides additional methods.
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 #pod =for test_synopsis
 #pod my ($st, $file);
@@ -288,7 +288,8 @@ sub filetype {
 #pod =cut
 
 sub isFile {
-    return -f $_[0];
+    # We make use of the File::stat version of the test to prevent unwanted croaks
+    return  File::stat::S_ISREG($_[0]->mode);
 }
 
 *isRegular = *isFile;
@@ -300,7 +301,8 @@ sub isFile {
 #pod =cut
 
 sub isDir {
-    return -d $_[0];
+    # We make use of the File::stat version of the test to prevent unwanted croaks
+    return  File::stat::S_ISDIR($_[0]->mode);
 }
 
 #pod =method isLink
@@ -312,7 +314,8 @@ sub isDir {
 #pod =cut
 
 sub isLink {
-    return -l $_[0];
+    # We make use of the File::stat version of the test to prevent unwanted croaks
+    return  File::stat::S_ISLNK($_[0]->mode);
 }
 
 #pod =method isBlock
@@ -322,7 +325,8 @@ sub isLink {
 #pod =cut
 
 sub isBlock {
-    return -b $_[0];
+    # We make use of the File::stat version of the test to prevent unwanted croaks
+    return  File::stat::S_ISBLK($_[0]->mode);
 }
 
 #pod =method isChar
@@ -332,7 +336,8 @@ sub isBlock {
 #pod =cut
 
 sub isChar {
-    return -c $_[0];
+    # We make use of the File::stat version of the test to prevent unwanted croaks
+    return  File::stat::S_ISCHR($_[0]->mode);
 }
 
 #pod =method isFIFO
@@ -344,7 +349,8 @@ sub isChar {
 #pod =cut
 
 sub isFIFO {
-    return -p $_[0];
+    # We make use of the File::stat version of the test to prevent unwanted croaks
+    return  File::stat::S_ISFIFO($_[0]->mode);
 }
 
 *isPipe = *isFIFO;
@@ -356,7 +362,8 @@ sub isFIFO {
 #pod =cut
 
 sub isSocket {
-    return -S $_[0];
+    # We make use of the File::stat version of the test to prevent unwanted croaks
+    return  File::stat::S_ISSOCK($_[0]->mode);
 }
 
 #pod =method -X operator
@@ -366,6 +373,9 @@ sub isSocket {
 #pod file system, these operators will use the information from the
 #pod object itself.
 #pod
+#pod The overloaded filetests are only supported from Perl version 5.12 and
+#pod higer. The named access to these tests can still be used though.
+#pod
 #pod Note: in case of the special file tests C<-t>, C<-T>, and C<-B>, the
 #pod file (handle) I<is> tested the I<first> time the operator is
 #pod used. After the first time, the initial result is re-used.
@@ -383,7 +393,16 @@ sub isSocket {
 #pod =cut
 
 my %op = (
-    # Defer implementation of normal tests to File::stat
+    # Use the named version of these tests
+    f => sub { $_[0]->isRegular },
+    d => sub { $_[0]->isDir },
+    l => sub { $_[0]->isLink },
+    p => sub { $_[0]->isFIFO },
+    S => sub { $_[0]->isSocket },
+    b => sub { $_[0]->isBlock },
+    c => sub { $_[0]->isChar },
+
+    # Defer implementation of rest to File::stat
     r => sub { -r $_[0][0] },
     w => sub { -w $_[0][0] },
     x => sub { -x $_[0][0] },
@@ -398,14 +417,6 @@ my %op = (
     z => sub { -z $_[0][0] },
     s => sub { -s $_[0][0] },
 
-    f => sub { -f $_[0][0] },
-    d => sub { -d $_[0][0] },
-    l => sub { -l $_[0][0] },
-    p => sub { -p $_[0][0] },
-    S => sub { -S $_[0][0] },
-    b => sub { -b $_[0][0] },
-    c => sub { -c $_[0][0] },
-
     u => sub { -u $_[0][0] },
     g => sub { -g $_[0][0] },
     k => sub { -k $_[0][0] },
@@ -455,7 +466,7 @@ File::stat::Extra - An extension of the File::stat module, provides additional m
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -642,6 +653,9 @@ just as you would on a file (handle). However, instead of querying the
 file system, these operators will use the information from the
 object itself.
 
+The overloaded filetests are only supported from Perl version 5.12 and
+higer. The named access to these tests can still be used though.
+
 Note: in case of the special file tests C<-t>, C<-T>, and C<-B>, the
 file (handle) I<is> tested the I<first> time the operator is
 used. After the first time, the initial result is re-used.
